#!/bin/sh
#
# rctl -- Digium R-Series control application
#
# Copyright (C) 2011, Digium, Inc.
#
# Keith Morgan <kmorgan@digium.com>
#
# This program is free software, distributed under the terms of
# the GNU General Public License Version 2.  See the COPYING file
# at the top of the source tree.
#

#
# Tests and gets info from Digium R-Series hardware.
#

VAR=`lsusb -v | grep "Digium R-Series"`
if [ -z "$VAR" ]; then
	echo "No R-Series hardware detected!"
	exit 0
else
	echo "R-Series hardware is detected!"
fi

RCTL=/sbin/rctl
if [ ! -f $RCTL ]; then
	echo "Please install rctl!"
	exit 0
fi

if [ -z "$2" ]; then
	for i in /dev/rseries{0,1,2,3,4,5,6,7}; do
		if [ -h $i ]; then
			# Found a /dev/rseriesX link.  Set it as the default.
			TTYDEV=$i
			break;
		fi
	done
else
	TTYDEV=$2
fi

main() {
	info
	tests
}

info() {
	$RCTL -t $TTYDEV --get-product-number --get-serial-number --get-firmware-version --get-port-count --get-id-switch --get-control-mode --get-watchdog -pall --get-port-status
}

tests() {
	echo "Executing these tests will disconect any in progress calls!"
	echo "Type 'YES' to continue"
	read line
	if [ $line != "YES" ]; then
		echo "Bye!"
		exit 0
	fi

	echo "Getting control and setting all ports to primary"
	$RCTL -t $TTYDEV --control-request -pall --set-port-status=0 >/dev/null
	echo ""
	sleep 2

	echo "Getting control and setting all ports to secondary"
	$RCTL -t $TTYDEV --control-request -pall --set-port-status=1 >/dev/null
	echo ""
	sleep 2

	echo "Getting control and setting all ports to primary"
	$RCTL -t $TTYDEV --control-request -pall --set-port-status=0 >/dev/null
	echo ""
	sleep 2

	i=`$RCTL -t $TTYDEV --get-port-count | cut -d ':' -f2 | cut -d ' ' -f2`
	echo "Switching relays one at a time"
	echo ""
	for c in `seq 1 $i`; do
		echo -n "Getting control and setting port $c to secondary..."
		VAR=`$RCTL -t $TTYDEV --control-request -p$c --set-port-status=1 --get-port-status | awk -F', ' '/Port [[:digit:]]+: / {print $2}'`
		if [ "$VAR" == "secondary" ]; then
			echo "Success!"
		else
			echo "Unit failed to report relay switch!"
			exit 0
		fi
		echo ""
		sleep 1

		echo -n "Getting control and setting port $c to primary..."
		VAR=`$RCTL -t $TTYDEV --control-request -p$c --set-port-status=0 --get-port-status | awk -F', ' '/Port [[:digit:]]+: / {print $2}'`
		if [ "$VAR" == "primary" ]; then
			echo "Success!"
		else
			echo "Unit failed to report relay switch!"
			exit 0
		fi
		echo ""
		sleep 1
	done
}

case "$1" in
all)
	main
	;;
info)
	info
	;;
tests)
	tests
	;;
*)
	echo "Usage: $0 {all|info|tests} [devicenode]"
	exit 1
esac
